//****************************************************************************
// FileName : WDLIB.CPP
// Function : Control Watch Dog Time Out.(for ITE IT8712F)
// Design's : By Ray
// BuildDate: 11/27/2002 V1.1
//****************************************************************************

//Include file as follows:
#include "wdlib.h"
#include <stdio.h>
#include <conio.h>

//Default value define as follows:
#define	equIndexPort	0x2e 	//super IO of index port for Super I/O
#define equDataPort	0x2f 	//super IO of data port for Super I/O
#define	equDeviceCR	0x07    //select super IO device of index port for Super I/O
#define	equLockReg	0x02	//lock super IO of configuration register for Supe I/O
//#define	equUnlockReg	0x87	//unlock super IO of configuration register for Super I/O

//==========================================================================//
// OpenIoConfig                                                             //
//==========================================================================//
// Function : open super IO of configuration register for Super I/O         //
// Enter    : None                                                          //
// Return   : None                                                          //
//==========================================================================//
void OpenIoConfig()
{
//super IO of index port for Super I/O
//unlock super IO of configuration register for Supe I/O
outportb(equIndexPort,0x87);
outportb(equIndexPort,0x01);
outportb(equIndexPort,0x55);
outportb(equIndexPort,0x55);
}

//==========================================================================//
// CloseIoConfig                                                            //
//==========================================================================//
// Function : close super IO of configuration register for Super I/O        //
// Enter    : None                                                          //
// Return   : None                                                          //
//==========================================================================//
void CloseIoConfig()
{
//super IO of index port for Super I/O
//lock super IO of configuration register for Super I/O
outportb(equIndexPort,0x02);
outportb(equDataPort,equLockReg);
}

//==========================================================================//
// SelectIoDevice                                                           //
//==========================================================================//
// Function : select super IO of device for Super I/O                       //
// Enter    : cSelectDEV = select device of function                        //
// Return   : None                                                          //
//==========================================================================//
void SelectIoDevice(char cSelectDEV)
{
//super IO of index port for Super I/O  
//select super IO device of index port for Super I/O
outportb(equIndexPort,equDeviceCR);

//super IO of data for Super I/O
//select device of function
outportb(equDataPort,cSelectDEV);
}

//==========================================================================//
// WriteIoCR                                                                //
//==========================================================================//
// Function : write super IO of configuration register for Supe I/O         //
// Enter    : cIndex = select index port of configuration register(CR)      //
//            cData  = configuration register of data                       //
// Return   : None                                                          //
//==========================================================================//
void WriteIoCR(char cIndex, char cData)
{
//super IO of index port for Super I/O
//select super IO of index register for Super I/O
outportb(equIndexPort,cIndex);

//super IO of data for Super I/O
//write data to data register
outportb(equDataPort,cData);
}

//==========================================================================//
// ReadIoCR                                                                 //
//==========================================================================//
// Function : read super IO of configuration register for Super I/O         //
// Enter    : cIndex = select index port of configuration register(CR)      //
// Return   : configuration register of data		                    //
//==========================================================================//
char ReadIoCR(char cIndex)
{
//super IO of index port for Super I/O
//select super IO of index register for Supe I/O
outportb(equIndexPort,cIndex);

//super IO of index port for Super I/O
//read data form index register
return (inportb(equDataPort));
}

//==========================================================================//
// InitWD                                                                   //
//==========================================================================//
// Function : initial watch dog                                             //
// Enter    : cSetTriggerSignal						    //
//               40h : RESET                                                //
//               03h : IRQ3                                                 //
//               04h : IRQ4                                                 //
//               05h : IRQ5                                                 //
//               06h : IRQ6                                                 //
//               07h : IRQ7                                                 //
//               09h : IRQ9                                                 //
//               0ah : IRQ10                                                //
//               0bh : IRQ11                                                //
//               0ch : IRQ12                                                //
//            cSetWatchDogUnit = watch dog counter of unit                  //
//               00h : minute                                               //
//               80h : second                                               //
// Return   : None                                                          //
//==========================================================================//
void InitWD(char cSetWatchDogUnit, char cSetTriggerSignal)
{
OpenIoConfig();		//open super IO of configuration for Super I/O

SelectIoDevice(0x07);	//select device7

//set watch dog counter of unit
WriteIoCR(0x72, cSetWatchDogUnit|cSetTriggerSignal);

//CloseIoConfig();		//close super IO of configuration for Super I/O
}

//==========================================================================//
// EnWD                                                                     //
//==========================================================================//
// Function : Enable watch dog                                              //
// Enter    : cWatchDogValue = watch dog time out of value                  //
// Return   : None                                                          //
//==========================================================================//
void EnWD(char cWatchDogValue)
{
char cReg;

OpenIoConfig();			//open super IO of configuration for Supe I/O

SelectIoDevice(0x07);	//select device7

//Tigger WatchDog
WriteIoCR(0x73, cWatchDogValue);

CloseIoConfig();		//close super IO of configuration for Super I/O
}

//==========================================================================//
// DisWD                                                                    //
//==========================================================================//
// Function : Disable watch dog                                             //
// Enter    : None              					    //
// Return   : None                                                          //
//==========================================================================//
void DisWD()
{
OpenIoConfig();			//open super IO of configuration for Supe I/O

SelectIoDevice(0x07);		//select device7

WriteIoCR(0x73, 0x00);

CloseIoConfig();		//close super IO of configuration for Super I/O
}
